@@ -8,7 +8,7 @@ import click
 from urllib.parse import urlparse
 
 from dramatiq.brokers.redis import RedisBroker
-
+from redis.sentinel import Sentinel
 from pypeline.extensions import pypeline_config
 from warnings import warn
 from apscheduler.schedulers.blocking import BlockingScheduler
@@ -30,6 +30,7 @@ from flask.cli import with_appcontext
 
 from pypeline.constants import (
     REDIS_URL,
+    REDIS_SENTINEL_MASTER_NAME,
     RABBIT_URL,
     DEFAULT_BROKER_CALLABLE,
     DEFAULT_BROKER_CONNECTION_HEARTBEAT,
@@ -37,6 +38,11 @@ from pypeline.constants import (
     DEFAULT_BROKER_CONNECTION_ATTEMPTS,
     MESSAGE_BROKER,
     DEFAULT_BROKER_HEARTBEAT_TIMEOUT,
+    DEFAULT_REDIS_SOCKET_CONNECT_TIMEOUT,
+    DEFAULT_REDIS_SOCKET_TIMEOUT,
+    DEFAULT_REDIS_RETRY_ON_TIMEOUT,
+    DEFAULT_REDIS_SOCKET_KEEPALIVE,
+    DEFAULT_REDIS_HEALTH_CHECK_INTERVAL,
 )
 from pypeline.pipelines.middleware.get_active_worker_id_middleware import (
     GetActiveWorkerIdMiddleware,
@@ -45,7 +51,8 @@ from pypeline.pipelines.middleware.parallel_pipeline_middleware import ParallelP
 from pypeline.pipelines.middleware.pypeline_middleware import PypelineMiddleware
 from pypeline.utils.config_utils import (
     retrieve_latest_schedule_config,
-    get_service_config_for_worker, retrieve_executable_job_config,
+    get_service_config_for_worker,
+    retrieve_executable_job_config,
 )
 from pypeline.utils.dramatiq_utils import (
     guess_code_directory,
@@ -62,7 +69,23 @@ logger = logging.getLogger(__name__)
 
 
 def configure_default_broker(broker: Broker = None):
-    redis_backend = RedisBackend(url=REDIS_URL)
+    redis_client = None
+    if REDIS_SENTINEL_MASTER_NAME is not None:
+        parsed_redis_url = urlparse(REDIS_URL)
+        redis_sentinel = Sentinel(
+            sentinels=[(parsed_redis_url.hostname, parsed_redis_url.port)],
+        )
+        redis_client = redis_sentinel.master_for(
+            REDIS_SENTINEL_MASTER_NAME,
+            db=int(parsed_redis_url.path[1]) if parsed_redis_url.path else 0,
+            password=parsed_redis_url.password,
+            socket_connect_timeout=DEFAULT_REDIS_SOCKET_CONNECT_TIMEOUT,
+            socket_timeout=DEFAULT_REDIS_SOCKET_TIMEOUT,
+            retry_on_timeout=DEFAULT_REDIS_RETRY_ON_TIMEOUT,
+            socket_keepalive=DEFAULT_REDIS_SOCKET_KEEPALIVE,
+            health_check_interval=DEFAULT_REDIS_HEALTH_CHECK_INTERVAL,
+        )
+    redis_backend = RedisBackend(client=redis_client, url=REDIS_URL)
 
     if MESSAGE_BROKER == "RABBITMQ":
         parsed_url = urlparse(RABBIT_URL)
@@ -85,7 +108,9 @@ def configure_default_broker(broker: Broker = None):
             broker
             if broker is not None
             else RedisBroker(
-                url=REDIS_URL, heartbeat_timeout=DEFAULT_BROKER_HEARTBEAT_TIMEOUT
+                client=redis_client,
+                url=REDIS_URL,
+                heartbeat_timeout=DEFAULT_BROKER_HEARTBEAT_TIMEOUT,
             )
         )
 
@@ -169,7 +194,6 @@ def register_actors_for_workers(broker: Broker):
                 logger.exception(f"Unable to add a task to dramatiq: {e}")
 
 
-
 class Dramatiq:
     """Flask extension bridging Dramatiq broker and Flask app.
 
