@@ -119,10 +119,9 @@ class TaskDefinitionsSchemaV1(ExcludeUnknownSchema):
 
     serverType = fields.String(
         required=False,
-        validate=OneOf(
-            ["xs", "s", "m", "l", "xl", "xxl", "xxxl", "cpu-xl"],
-            error="Invalid serverType. Available options: 'xs', 's', 'm', 'l', 'xl', 'xxl', 'xxxl', 'cpu-xl'.",
-        ),
+        description="Recommended presets are listed in enum; custom strings are allowed.",
+        example="m",
+        metadata={"enum": ["xs", "s", "m", "l", "xl", "xxl", "xxxl", "cpu-xl"]},  # docs only
     )
 
 
@@ -151,10 +150,9 @@ class TaskDefinitionsSchemaV2(ExcludeUnknownSchema):
 
     serverType = fields.String(
         required=False,
-        validate=OneOf(
-            ["xs", "s", "m", "l", "xl", "xxl", "xxxl", "cpu-xl"],
-            error="Invalid serverType. Available options: 'xs', 's', 'm', 'l', 'xl', 'xxl', 'xxxl', 'cpu-xl'.",
-        ),
+        description="Recommended presets are listed in enum; custom strings are allowed.",
+        example="m",
+        metadata={"enum": ["xs", "s", "m", "l", "xl", "xxl", "xxxl", "cpu-xl"]},  # docs only
     )
 
 
