@@ -76,7 +76,13 @@ class PypelineMiddleware(Middleware):
                 # If the lock didn't exist for the current tasks execution id then it would indicate
                 # that this is the start of a new scenario.  Therefore we need to find the ancestor
                 # that is executed in the base case execution id and make sure it has completed
-                if remaining_tasks is None:
+                tasks_to_run_in_scenario = None
+
+                for scenario in message.options["scenarios"]:
+                    if scenario["execution_id"] == execution_id:
+                        tasks_to_run_in_scenario = scenario["tasksToRunInScenario"]
+
+                if ancestor not in tasks_to_run_in_scenario and remaining_tasks is None:
                     ancestor_task_key = (
                         f"{message.options['base_case_execution_id']}-{ancestor}"
                     )
@@ -95,15 +101,17 @@ class PypelineMiddleware(Middleware):
                             remaining_tasks = locking_parallel_barrier.get_task_count()
                     finally:
                         locking_parallel_barrier.release_lock()
+
+
                 if remaining_tasks is None or remaining_tasks >= 1:
                     ancestor_tasks_complete = False
                     break
 
             # If the child's ancestor tasks aren't complete move onto the next child to check
             if not ancestor_tasks_complete:
-                break
+                continue
 
-            # Handle situation where base case kicks off new scenario
+            # Handle situation where base case kicks off new scenario.
             if (
                 message.options["base_case_execution_id"]
                 == message.options["execution_id"]
@@ -160,7 +168,7 @@ class PypelineMiddleware(Middleware):
                             )
                         messages.append(scenario_message)
 
-            # Kick off child task for current scenario
+            # If we've made it here all ancestors of this child are complete and it's time to run.
             task_key = f"{execution_id}-{child}"
             locking_parallel_barrier = LockingParallelBarrier(
                 self.redis_url,
