@@ -27,9 +27,12 @@ def enable_graceful_shutdown(broker, redis_url):
 
         def shutdown_handler(signum, frame):
             logger.info(f"[Signal Handler] Received signal {signum}")
+            wait_counter = 0
             while r.get(busy_key):
-                logger.info(f"[Signal Handler] Busy ({busy_key}), waiting...")
-                time.sleep(30)
+                if wait_counter % 30 == 0:  # Only log every 30 checks
+                    logger.info(f"[Signal Handler] Busy ({busy_key}), waiting...")
+                time.sleep(1)
+                wait_counter += 1
             logger.info(f"[Signal Handler] Done. Exiting.")
             sys.exit(0)
 
